@@ -10,7 +10,7 @@ First, you must define the following glyph classes:
 
 - ``@inits``: all initial forms
 - ``@medis``: all medial forms
-- ``@bari_ye``: all forms of final bari ye or glyphs that you wish to treat
+- ``@bariye``: all forms of final bari ye or glyphs that you wish to treat
   *like* bari ye. For example, final jim and final choti ye may have "bari ye
   like tendencies" in that they have a large negative right sidebearing that
   requires nukta repositioning.
@@ -44,7 +44,7 @@ alif from being "drawn in" to the bari ye.
 ``BYFixOverhang`` takes an integer
 value (an additional number of points to separate the end of the bari ye tail
 and the following glyph), and computes rules which act only on short sequences;
-it evalutes all possible short sequences (using width-binning to keep the number
+it evaluates all possible short sequences (using width-binning to keep the number
 of combinations to a reasonable number), computes the total width of each
 sequence, compares this against the negative RSB of the bari ye, and
 emits appropriate kerning rules to generate the desired separation. e.g.
@@ -52,6 +52,11 @@ emits appropriate kerning rules to generate the desired separation. e.g.
 between the end of the tail of each glyph in ``@bariye`` and any isolated/final
 glyph preceding the sequence.
 
+``BYFixOverhang`` can also take an optional integer value for the adjustment
+threshold, any adjustments less than the threshold will be dropped. e.g.
+``BYFixOverhang 10 100 @bariye`` will drop any adjustments that are less than
+100 units.
+
 """
 
 
@@ -86,7 +91,7 @@ STRATEGY: "AlwaysDrop" | "TryToFit"
 
 BYFixOverhang_GRAMMAR = """
 ?start: action
-action: integer_container glyphselector
+action: integer_container integer_container? glyphselector
 """
 
 VERBS = ["BYMoveDots", "BYFixOverhang"]
@@ -375,12 +380,17 @@ class BYMoveDots(FEZVerb):
 
 class BYFixOverhang(FEZVerb):
     def action(self, args):
-        overhang_padding, glyphs = args
+        if len(args) == 3:
+            overhang_padding, adjustment_threshold, glyphs = args
+            adjustment_threshold = adjustment_threshold.resolve_as_integer()
+        else:
+            overhang_padding, glyphs = args
+            adjustment_threshold = None
         overhang_padding = overhang_padding.resolve_as_integer()
         parser = self.parser
         for c in ["inits", "medis"]:
             if c not in parser.fontfeatures.namedClasses:
-                raise ValueError("Please define @%s class before calling")
+                raise ValueError("Please define @%s class before calling" % c)
 
         medis = parser.fontfeatures.namedClasses["medis"]
         inits = parser.fontfeatures.namedClasses["inits"]
@@ -406,6 +416,8 @@ class BYFixOverhang(FEZVerb):
                     continue
 
                 adjustment = overhang - totalwidth + int(overhang_padding)
+                if adjustment_threshold is not None and adjustment < adjustment_threshold:
+                    continue
                 postcontext = [x[0] for x in string[:-1]] + [[yb]]
                 input_ = string[-1]
                 example = [input_[0][0]] + [x[0] for x in postcontext]
